==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPaneHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebPaneHeaderElementDescription } from "./WebPaneHeaderElementDescription";
/**
 * @hidden
 */
var WebPaneHeaderElementDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneHeaderElementDescriptionMetadata, _super);
    function WebPaneHeaderElementDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneHeaderElementDescriptionMetadata.b = function (a) {
        if (WebPaneHeaderElementDescriptionMetadata.a == null) {
            WebPaneHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneHeaderElementDescriptionMetadata.c(WebPaneHeaderElementDescriptionMetadata.a);
        }
        if (a.j(WebPaneHeaderElementDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPaneHeaderElementDescriptionMetadata.a);
        WebDragServiceDescriptionMetadata.d(a);
    };
    WebPaneHeaderElementDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneHeaderElement");
        a.item("DragService", "ExportedType:WebDragService");
    };
    WebPaneHeaderElementDescriptionMetadata.d = function (a) {
        WebPaneHeaderElementDescriptionMetadata.b(a);
        a.aa("WebPaneHeaderElement", function () { return new WebPaneHeaderElementDescription(); });
        a.z("WebPaneHeaderElement", WebPaneHeaderElementDescriptionMetadata.a);
    };
    WebPaneHeaderElementDescriptionMetadata.$t = markType(WebPaneHeaderElementDescriptionMetadata, 'WebPaneHeaderElementDescriptionMetadata');
    WebPaneHeaderElementDescriptionMetadata.a = null;
    return WebPaneHeaderElementDescriptionMetadata;
}(Base));
export { WebPaneHeaderElementDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPaneHeaderElementDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDragServiceDescriptionMetadata } from "./WebDragServiceDescriptionMetadata";
import { WebPaneHeaderElementDescription } from "./WebPaneHeaderElementDescription";
/**
 * @hidden
 */
var WebPaneHeaderElementDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPaneHeaderElementDescriptionMetadata, _super);
    function WebPaneHeaderElementDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPaneHeaderElementDescriptionMetadata.b = function (a) {
        if (WebPaneHeaderElementDescriptionMetadata.a == null) {
            WebPaneHeaderElementDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPaneHeaderElementDescriptionMetadata.c(WebPaneHeaderElementDescriptionMetadata.a);
        }
        if (a.k(WebPaneHeaderElementDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPaneHeaderElementDescriptionMetadata.a);
        WebDragServiceDescriptionMetadata.d(a);
    };
    WebPaneHeaderElementDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PaneHeaderElement");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("DragService", "ExportedType:WebDragService");
    };
    WebPaneHeaderElementDescriptionMetadata.d = function (a) {
        WebPaneHeaderElementDescriptionMetadata.b(a);
        a.ac("WebPaneHeaderElement", function () { return new WebPaneHeaderElementDescription(); });
        a.ab("WebPaneHeaderElement", WebPaneHeaderElementDescriptionMetadata.a);
    };
    WebPaneHeaderElementDescriptionMetadata.$t = markType(WebPaneHeaderElementDescriptionMetadata, 'WebPaneHeaderElementDescriptionMetadata');
    WebPaneHeaderElementDescriptionMetadata.a = null;
    return WebPaneHeaderElementDescriptionMetadata;
}(Base));
export { WebPaneHeaderElementDescriptionMetadata };
